#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ENUMERATE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ENUMERATE_HPP_INCLUDED

#include <nt2/swar/include/functions/scalar/enumerate.hpp>

#endif
